#  Copyright (c) XiaoLinpeng 2020.

# !/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   version.py    
@Contact :   1553990434@qq.com
@License :   (C)Copyright 2019-Present, XiaoLinpeng

@Modify Time      @Author    @Version    @Description
------------      -------    --------    -----------
2020-04-09 07:07   肖林朋      1.0         版本测试
"""


def version():
    """
    打印版本信息
    :return:
    """
    print('DataFushion_Plugins_SparkPy V1.0.0')
